@@ -1,6 +1,8 @@
 """Flask app for looking at information in regolith."""
 import json
 import traceback
+import tempfile
+import os
 
 from flask import Flask, abort, request, render_template, redirect, url_for
 
@@ -22,6 +24,7 @@ def shutdown_server():
         raise RuntimeError('Not running with the Werkzeug Server')
     func()
 
+
 @app.route('/shutdown', methods=['GET', 'POST'])
 def shutdown():
     shutdown_server()
@@ -48,6 +51,12 @@ def collection_page(dbname, collname):
             try:
                 body = json.loads(form['body'].strip())
             except Exception:
+                td = tempfile.TemporaryDirectory()
+                n = os.path.join(td.name, 'regolith.txt')
+                print('Error in json parsing writing text file to {}. '
+                      'Please try again.'.format(n))
+                with open(n) as f:
+                    f.write(form['body'])
                 traceback.print_exc()
                 raise
             rc.client.update_one(dbname, collname, {'_id': body['_id']}, body)
@@ -58,6 +67,12 @@ def collection_page(dbname, collname):
                 body = json.loads(form['body'].strip())
                 print(body)
             except Exception:
+                td = tempfile.TemporaryDirectory()
+                n = os.path.join(td.name, 'regolith.txt')
+                print('Error in json parsing writing text file to {}. '
+                      'Please try again.'.format(n))
+                with open(n) as f:
+                    f.write(form['body'])
                 traceback.print_exc()
                 raise
             try:
@@ -70,6 +85,7 @@ def collection_page(dbname, collname):
         elif 'delete' in form:
             body = json.loads(form['body'].strip())
             deled = rc.client.delete_one(dbname, collname, body)
-    return render_template('collection.html', rc=rc, dbname=dbname, len=len, str=str,
+    return render_template('collection.html', rc=rc, dbname=dbname, len=len,
+                           str=str,
                            status=status, status_id=status_id,
                            collname=collname, coll=coll, json=json, min=min)
